# coding: utf-8

"""
    clusterapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kaistack.clients.openapi_clients.cluster.configuration import Configuration


class CodegenNode(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'node_name': 'str',
        'status': 'str',
        'resources': 'dict(str, str)',
        'labels': 'dict(str, str)',
        'annotations': 'dict(str, str)',
        'resource_usage': 'dict(str, float)'
    }

    attribute_map = {
        'node_name': 'nodeName',
        'status': 'status',
        'resources': 'resources',
        'labels': 'labels',
        'annotations': 'annotations',
        'resource_usage': 'resourceUsage'
    }

    def __init__(self, node_name=None, status=None, resources=None, labels=None, annotations=None, resource_usage=None, local_vars_configuration=None):  # noqa: E501
        """CodegenNode - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._node_name = None
        self._status = None
        self._resources = None
        self._labels = None
        self._annotations = None
        self._resource_usage = None
        self.discriminator = None

        if node_name is not None:
            self.node_name = node_name
        if status is not None:
            self.status = status
        if resources is not None:
            self.resources = resources
        if labels is not None:
            self.labels = labels
        if annotations is not None:
            self.annotations = annotations
        if resource_usage is not None:
            self.resource_usage = resource_usage

    @property
    def node_name(self):
        """Gets the node_name of this CodegenNode.  # noqa: E501


        :return: The node_name of this CodegenNode.  # noqa: E501
        :rtype: str
        """
        return self._node_name

    @node_name.setter
    def node_name(self, node_name):
        """Sets the node_name of this CodegenNode.


        :param node_name: The node_name of this CodegenNode.  # noqa: E501
        :type: str
        """

        self._node_name = node_name

    @property
    def status(self):
        """Gets the status of this CodegenNode.  # noqa: E501


        :return: The status of this CodegenNode.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CodegenNode.


        :param status: The status of this CodegenNode.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def resources(self):
        """Gets the resources of this CodegenNode.  # noqa: E501


        :return: The resources of this CodegenNode.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this CodegenNode.


        :param resources: The resources of this CodegenNode.  # noqa: E501
        :type: dict(str, str)
        """

        self._resources = resources

    @property
    def labels(self):
        """Gets the labels of this CodegenNode.  # noqa: E501


        :return: The labels of this CodegenNode.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this CodegenNode.


        :param labels: The labels of this CodegenNode.  # noqa: E501
        :type: dict(str, str)
        """

        self._labels = labels

    @property
    def annotations(self):
        """Gets the annotations of this CodegenNode.  # noqa: E501


        :return: The annotations of this CodegenNode.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this CodegenNode.


        :param annotations: The annotations of this CodegenNode.  # noqa: E501
        :type: dict(str, str)
        """

        self._annotations = annotations

    @property
    def resource_usage(self):
        """Gets the resource_usage of this CodegenNode.  # noqa: E501


        :return: The resource_usage of this CodegenNode.  # noqa: E501
        :rtype: dict(str, float)
        """
        return self._resource_usage

    @resource_usage.setter
    def resource_usage(self, resource_usage):
        """Sets the resource_usage of this CodegenNode.


        :param resource_usage: The resource_usage of this CodegenNode.  # noqa: E501
        :type: dict(str, float)
        """

        self._resource_usage = resource_usage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CodegenNode):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CodegenNode):
            return True

        return self.to_dict() != other.to_dict()
