# coding: utf-8

"""
    clusterapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import kaistack.clients.openapi_clients.cluster
from kaistack.clients.openapi_clients.cluster.api.cluster_service_api import ClusterServiceApi  # noqa: E501
from kaistack.clients.openapi_clients.cluster.rest import ApiException


class TestClusterServiceApi(unittest.TestCase):
    """ClusterServiceApi unit test stubs"""

    def setUp(self):
        self.api = kaistack.clients.openapi_clients.cluster.api.cluster_service_api.ClusterServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_nodes(self):
        """Test case for get_nodes

        """
        pass


if __name__ == '__main__':
    unittest.main()
