# coding: utf-8

"""
    workflowapis.proto

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: version not set
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import kaistack.clients.openapi_clients.workflow
from kaistack.clients.openapi_clients.workflow.api.workflow_service_api import WorkflowServiceApi  # noqa: E501
from kaistack.clients.openapi_clients.workflow.rest import ApiException


class TestWorkflowServiceApi(unittest.TestCase):
    """WorkflowServiceApi unit test stubs"""

    def setUp(self):
        self.api = kaistack.clients.openapi_clients.workflow.api.workflow_service_api.WorkflowServiceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_run(self):
        """Test case for create_run

        """
        pass

    def test_get_argo_workflow(self):
        """Test case for get_argo_workflow

        """
        pass

    def test_get_artifact_with_properties(self):
        """Test case for get_artifact_with_properties

        """
        pass

    def test_get_artifacts_with_filter(self):
        """Test case for get_artifacts_with_filter

        """
        pass

    def test_get_metrics(self):
        """Test case for get_metrics

        """
        pass

    def test_get_params(self):
        """Test case for get_params

        """
        pass

    def test_get_pipeline_experiment_name(self):
        """Test case for get_pipeline_experiment_name

        """
        pass

    def test_get_pipeline_run_id(self):
        """Test case for get_pipeline_run_id

        """
        pass

    def test_get_pipeline_runs(self):
        """Test case for get_pipeline_runs

        """
        pass

    def test_get_run(self):
        """Test case for get_run

        """
        pass

    def test_get_run_by_name(self):
        """Test case for get_run_by_name

        """
        pass

    def test_log_artifact_meta(self):
        """Test case for log_artifact_meta

        """
        pass

    def test_log_metrics(self):
        """Test case for log_metrics

        """
        pass

    def test_log_params(self):
        """Test case for log_params

        """
        pass


if __name__ == '__main__':
    unittest.main()
